@@ -451,8 +451,8 @@ def FieldDetermination(Fields,plot=False,**kwargs):
     Examples
     --------
     Dictionary :
-    >>>> posições = {'circ': ['0','200','200','50','0'  ,'0'  ,'0' ,'0' ],
-    >>>>             'rect': ['1','0'  ,'0'  ,'0' ,'400','200','75','75'],}
+    >>>> posições = {'circ': [0,200,200,50,0  ,0  ,0 ,0 ],
+    >>>>             'rect': [1,0  ,0  ,0 ,400,200,75,75],}
 
     See Also
     --------
@@ -518,11 +518,14 @@ def FieldDetermination(Fields,plot=False,**kwargs):
                 df2 = pd.DataFrame([[objectType, null,null, null ,aX,aY,height,width]], columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y' , 'height', 'width'])
             fields = fields.append(df2, ignore_index=True)
     else:
-        for v in posit:
+        for i,v in enumerate(posit):
             df2 = pd.DataFrame([[posit[v][0], posit[v][1], posit[v][2],posit[v][3],posit[v][4],posit[v][5],posit[v][6],posit[v][7]]], 
                                  columns=['fields','center_x','center_y', 'radius', 'a_x', 'a_y','height', 'width'])
-            rect.append(patches.Rectangle((float(posit[v][4]),float(posit[v][5])), float(posit[v][6]), float(posit[v][7]), linewidth=1, edgecolor=obj_color, facecolor='none'))
-            circle.append(plt.Circle((float(posit[v][1]),float(posit[v][2])), float(posit[v][3]), color=obj_color,fill = False))
+            if posit[v][0] == 1:
+                rect.append(patches.Rectangle((float(posit[v][4]),float(posit[v][5])), float(posit[v][6]), float(posit[v][7]), linewidth=1, edgecolor=obj_color, facecolor='none'))
+                print(posit[v][0])
+            if posit[v][0] == 0:
+                circle.append(plt.Circle((float(posit[v][1]),float(posit[v][2])), float(posit[v][3]), color=obj_color,fill = False))
             fields = fields.append(df2, ignore_index=True)
 
     if plot:
@@ -558,7 +561,7 @@ def Interaction(data,bodyPart,fields,fps=30):
     Returns
     -------
     out : int
-        Scale factor of your box.
+        DataFrame with all interactions. 0 = no interaction; 1 = first object; 2 = second object...
 
     See Also
     --------
